@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2015 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2015 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2016 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2016 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -36,6 +36,7 @@ def register():
         BirthCertificate,
         DeathCertificate,
         PartyPatient,
+        PersonName,
         PartyAddress,
         DrugDoseUnits,
         MedicationFrequency,
@@ -72,8 +73,6 @@ def register():
         InsurancePlan,
         Insurance,
         AlternativePersonID,
-        ProductCategory,
-        ProductTemplate,
         Product,
         GnuHealthSequences,
         PatientData,
@@ -81,15 +80,16 @@ def register():
         Appointment,
         AppointmentReport,
         OpenAppointmentReportStart,
-        PatientMedication,
-        PatientVaccination,
         PatientPrescriptionOrder,
         PrescriptionLine,
+        PatientMedication,
+        PatientVaccination,
         PatientEvaluation,
         Directions,
         SecondaryCondition,
         DiagnosticHypothesis,
         SignsAndSymptoms,
+        PatientECG,
         CheckImmunizationStatusInit,
         module='health', type_='model')
     Pool.register(
